@@ -13,10 +13,8 @@ from language_formatters_pre_commit_hooks.utils import download_url
 from language_formatters_pre_commit_hooks.utils import run_command
 
 
-def __download_kotlin_formatter_jar(version):  # pragma: no cover
-    # type: (typing.Text) -> typing.Text
-    def get_url(_version):
-        # type: (typing.Text) -> typing.Text
+def __download_kotlin_formatter_jar(version: str) -> str:  # pragma: no cover
+    def get_url(_version: str) -> str:
         # Links extracted from https://github.com/pinterest/ktlint/
         return "https://github.com/pinterest/ktlint/releases/download/{version}/ktlint".format(
             version=_version,
@@ -36,8 +34,7 @@ def __download_kotlin_formatter_jar(version):  # pragma: no cover
 
 
 @java_required
-def pretty_format_kotlin(argv=None):
-    # type: (typing.Optional[typing.List[typing.Text]]) -> int
+def pretty_format_kotlin(argv: typing.Optional[typing.List[str]] = None) -> int:
     parser = argparse.ArgumentParser()
     parser.add_argument(
         "--autofix",
@@ -65,7 +62,7 @@ def pretty_format_kotlin(argv=None):
     # mode if autofix flag is enabled
     check_status, check_output = run_command("java", "-jar", ktlint_jar, "--verbose", "--relative", "--", *args.filenames)
 
-    not_pretty_formatted_files = set()  # type: typing.Set[typing.Text]
+    not_pretty_formatted_files: typing.Set[str] = set()
     if check_status != 0:
         not_pretty_formatted_files.update(line.split(":", 1)[0] for line in check_output.splitlines())
 
